#
# spec file for package xmvn-tools
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global parent xmvn
%global subname tools
Name:           %{parent}-%{subname}
Version:        4.2.0
Release:        150200.3.24.2
Summary:        Local Extensions for Apache Maven
License:        Apache-2.0
Group:          Development/Tools/Building
URL:            https://fedora-java.github.io/xmvn/
Source0:        https://github.com/fedora-java/xmvn/releases/download/%{version}/%{parent}-%{version}.tar.xz
Source1:        %{parent}-build.tar.xz
Patch0:         UUID.patch
Patch1:         0001-Do-not-leave-a-stray-options-file-in-the-generated-j.patch
BuildRequires:  ant
BuildRequires:  apache-commons-compress
BuildRequires:  apache-commons-io
BuildRequires:  atinject
BuildRequires:  beust-jcommander >= 1.82
BuildRequires:  fdupes
BuildRequires:  java-devel >= 1.8
BuildRequires:  javapackages-local
BuildRequires:  modello >= 2.0.0
BuildRequires:  objectweb-asm
BuildRequires:  sisu-inject
BuildRequires:  sisu-plexus
BuildRequires:  slf4j
BuildArch:      noarch

%description
This package provides extensions for Apache Maven that can be used to
manage system artifact repository and use it to resolve Maven
artifacts in offline mode, as well as Maven plugins to help with
creating RPM packages containing Maven artifacts.

%package -n %{parent}-api
Summary:        XMvn API
Group:          Development/Tools/Building

%description -n %{parent}-api
This package provides XMvn API module which contains public interface
for functionality implemented by XMvn Core.

%package -n %{parent}-core
Summary:        XMvn Core
Group:          Development/Tools/Building

%description -n %{parent}-core
This package provides XMvn Core module, which implements the essential
functionality of XMvn such as resolution of artifacts from system
repository.

%package -n %{parent}-resolve
Summary:        XMvn Resolver
# Explicit javapackages-tools requires since scripts use
# /usr/share/java-utils/java-functions
Group:          Development/Tools/Building
Requires:       %{parent}-api = %{version}
Requires:       %{parent}-core = %{version}
Requires:       beust-jcommander >= 1.82
Requires:       javapackages-tools

%description -n %{parent}-resolve
This package provides XMvn Resolver, which is a very simple
command-line tool to resolve Maven artifacts from system repositories.
Basically it's just an interface to artifact resolution mechanism
implemented by XMvn Core.  The primary intended use case of XMvn
Resolver is debugging local artifact repositories.

%package -n %{parent}-subst
Summary:        XMvn Subst
# Explicit javapackages-tools requires since scripts use
# /usr/share/java-utils/java-functions
Group:          Development/Tools/Building
Requires:       %{parent}-api = %{version}
Requires:       %{parent}-core = %{version}
Requires:       beust-jcommander
Requires:       javapackages-tools

%description -n %{parent}-subst
This package provides XMvn Subst, which is a tool that can substitute
Maven artifact files with symbolic links to corresponding files in
artifact repository.

%package -n %{parent}-install
Summary:        XMvn Install
# Explicit javapackages-tools requires since scripts use
# /usr/share/java-utils/java-functions
Group:          Development/Tools/Building
Requires:       %{parent}-api = %{version}
Requires:       %{parent}-core = %{version}
Requires:       apache-commons-compress
Requires:       apache-commons-io
Requires:       beust-jcommander
Requires:       javapackages-tools
Requires:       objectweb-asm
Requires:       slf4j

%description -n %{parent}-install
This package provides XMvn Install, which is a command-line interface
to XMvn installer.  The installer reads reactor metadata and performs
artifact installation according to specified configuration.

%package javadoc
Summary:        API documentation for %{name}
Group:          Documentation/HTML
Obsoletes:      javadoc

%description javadoc
This package provides %{summary}.

%prep
%setup -q -n %{parent}-%{version} -a1

%autopatch -p1

# Resolver IT won't work either - it tries to execute JAR file, which
# relies on Class-Path in manifest, which is forbidden in Fedora...
find -name ResolverIntegrationTest.java -delete

%pom_remove_plugin -r :maven-site-plugin

# Upstream code quality checks, not relevant when building RPMs
%pom_remove_plugin -r :apache-rat-plugin
%pom_remove_plugin -r :maven-checkstyle-plugin
%pom_remove_plugin -r :jacoco-maven-plugin
# FIXME pom macros don't seem to support submodules in profile
%pom_remove_plugin :jacoco-maven-plugin xmvn-it

# remove dependency plugin maven-binaries execution
# we provide apache-maven by symlink
%pom_xpath_remove "pom:executions/pom:execution[pom:id[text()='maven-binaries']]"

# Don't put Class-Path attributes in manifests
%pom_remove_plugin :maven-jar-plugin xmvn-tools

# This test depends on OpenJDK directory layout that changed since version 9
%if %{?pkg_vcmp:%pkg_vcmp java-devel >= 9}%{!?pkg_vcmp:0}
rm -f xmvn-core/src/test/java/org/fedoraproject/xmvn/resolver/JavaHomeResolverTest.java
%endif

for i in api core; do
  %pom_xpath_inject "pom:project" "
     <groupId>org.fedoraproject.xmvn</groupId>
     <version>%{version}</version>" %{parent}-${i}
  %pom_remove_parent %{parent}-${i}
done
for i in install resolve subst; do
  %pom_xpath_inject "pom:project" "
     <groupId>org.fedoraproject.xmvn</groupId>
     <version>%{version}</version>" %{parent}-tools/%{parent}-${i}
  %pom_remove_parent %{parent}-tools/%{parent}-${i}
done

%build
mkdir -p lib
build-jar-repository -s lib \
  atinject \
  beust-jcommander \
  commons-compress \
  objectweb-asm/asm \
  org.eclipse.sisu.inject \
  org.eclipse.sisu.plexus \
  slf4j/api

%{ant} -Dtest.skip=true package javadoc

%install
# jars
install -dm 0755 %{buildroot}%{_javadir}/%{parent}
for i in api core; do
  install -pm 0644 %{parent}-${i}/target/%{parent}-${i}-%{version}.jar %{buildroot}%{_javadir}/%{parent}/%{parent}-${i}.jar
done
for i in install resolve subst; do
  install -pm 0644 %{parent}-tools/%{parent}-${i}/target/%{parent}-${i}-%{version}.jar %{buildroot}%{_javadir}/%{parent}/%{parent}-${i}.jar
done

# poms
install -dm 0755 %{buildroot}%{_mavenpomdir}/%{parent}
for i in api core; do
  install -pm 0644 %{parent}-${i}/pom.xml %{buildroot}%{_mavenpomdir}/%{parent}/%{parent}-${i}.pom
  %add_maven_depmap %{parent}/%{parent}-${i}.pom %{parent}/%{parent}-${i}.jar -f ${i}
done
for i in install resolve subst; do
  install -pm 0644 %{parent}-tools/%{parent}-${i}/pom.xml %{buildroot}%{_mavenpomdir}/%{parent}/%{parent}-${i}.pom
  %add_maven_depmap %{parent}/%{parent}-${i}.pom %{parent}/%{parent}-${i}.jar -f ${i}
done

# javadoc
install -dm 0755 %{buildroot}%{_javadocdir}/%{parent}
for i in api core; do
  install -dm 0755 %{buildroot}%{_javadocdir}/%{parent}/${i}
  cp -pr %{parent}-${i}/target/site/apidocs/* %{buildroot}%{_javadocdir}/%{parent}/${i}/
done
for i in install resolve subst; do
  install -dm 0755 %{buildroot}%{_javadocdir}/%{parent}/${i}
  cp -pr %{parent}-tools/%{parent}-${i}/target/site/apidocs/* %{buildroot}%{_javadocdir}/%{parent}/${i}/
done
%fdupes -s %{buildroot}%{_javadocdir}

# helper scripts
%jpackage_script org.fedoraproject.xmvn.tools.install.cli.InstallerCli "" "" %{parent}/%{parent}-install:%{parent}/%{parent}-api:%{parent}/%{parent}-core:beust-jcommander:slf4j/api:slf4j/simple:objectweb-asm/asm:commons-compress:commons-io %{parent}-install
%jpackage_script org.fedoraproject.xmvn.tools.resolve.ResolverCli "" "" %{parent}/%{parent}-resolve:%{parent}/%{parent}-api:%{parent}/%{parent}-core:beust-jcommander %{parent}-resolve
%jpackage_script org.fedoraproject.xmvn.tools.subst.SubstCli "" "" %{parent}/%{parent}-subst:%{parent}/%{parent}-api:%{parent}/%{parent}-core:beust-jcommander %{parent}-subst

%files -n %{parent}-core -f .mfiles-core

%files -n %{parent}-api -f .mfiles-api
%license LICENSE NOTICE
%doc AUTHORS README.md

%files -n %{parent}-resolve -f .mfiles-resolve
%{_bindir}/%{parent}-resolve

%files -n %{parent}-subst -f .mfiles-subst
%{_bindir}/%{parent}-subst

%files -n %{parent}-install -f .mfiles-install
%{_bindir}/%{parent}-install

%files javadoc
%license LICENSE NOTICE
%{_javadocdir}/%{parent}

%changelog
* Mon Feb 19 2024 fstrba@suse.com
- Modify the xmvn-install script to work with new
  apache-commons-compress
* Tue Jan 30 2024 fstrba@suse.com
- Modified patch:
  * UUID.patch
    + sync with the version in our official upstream pull request
* Wed Sep 13 2023 fstrba@suse.com
- Added patch:
  * 0001-Do-not-leave-a-stray-options-file-in-the-generated-j.patch
    + Remove generated temporary file from the tree after use, make
    thus the generated javadoc more reproducible
* Wed Aug  2 2023 fstrba@suse.com
- Modified patch:
  * UUID.patch
    + try to assure unique UUID for each of the split packages.
* Mon Jul 24 2023 fstrba@suse.com
- Added patch:
  * UUID.patch
    + avoid generating random UUIDs, which makes reproducible build
    impossible (bsc#1162112)
* Wed May  3 2023 fstrba@suse.com
- Upgrade to version 4.2.0
  * Changes:
    + Make XMvn Resolver log to XMvn Logger
    + Make XMvn Subst log to XMvn Logger
    + Depend on junit-jupiter-api instead of junit-jupiter
    + Suppress deprecation warnings in MavenExtensionTest
    + Remove XMvn Connector dependency on Plexus Utils
    + Remove XMvn MOJO dependency on Plexus Utils
    + Port XMvn MOJO from Xpp3Dom to StAX
    + Update Maven to version 3.9.1
    + Don't pass duplicate --patch-module to javadoc
    + Make Javadoc MOJO respect ignoreJPMS configuration flag
    + Propagate javadoc output througt Logger
    + Remove dependency on Plexus Classworlds
    + Remove unneeded managed dependency on maven-invoker
    + Use ServiceLocator to find Logger
    + Use parametrized logging feature
    + Use XMvn Logger instead of Plexus Logger
    + Get rid of Slf4jLoggerAdapter
    + Drop support for Gossip logger
    + Move XMvn Logger to API module
    + Ignore JPMS when all modules are automatic
    + Refactor Javadoc MOJO
    + Make Javadoc not fail when no sources are found
    + Add an integration test for javadoc generation with
    module-info.java but no sources
    + Add an integration test for javadoc generation with
    Automatic-Module-Name
    + Make Javadoc MOJO work in case one of JPMS modules has no
    sources
    + Prioritize certain XMvn components over Maven components
    + Port XMvn MOJO to JSR-330
    + Refactor XMvnMojoExecutionConfigurator
    + Make builddep MOJO compatible with Maven 4
    + Port to JSR-330
    + Get rid of ModelProcessor
    + Refactor XMvnModelValidator
    + Refactor XMvnToolchainManager
    + Convert lambda to method reference
    + Improve Javadoc MOJO JPMS support
    + Add a test case for JPMS javadoc generation with remote
    dependencies
    + Add a test case for JPMS multimodule javadoc generation
    + Exclude src/test/resources-filtered/** from RAT
    + Fix scope of xmvn-mojo dependency on plexus-utils
    + --module-path not allowed with release=8
    + Mimic maven-javadoc-plugin for -source and --release
    + testJavadocJPMS needs a modular java
    + Let modello generate source 8
    + Add a jdk9+ profile to assure that we are jdk8 compatible
    + Revert "Use new Collection methods added in Java 9"
    + Revert "Update compiler source/target to JDK 11"
    + Restore possibility to build with Java 8
    + Simple implementation of toolchains
    https://github.com/fedora-java/xmvn/issues/142
    + Port to Modello 2.0.0
- Removed patches
  * 0001-Mimic-maven-javadoc-plugin-for-source-and-release.patch
  * 0001-Port-to-Maven-3.8.5.patch
  * 0001-Restore-possibility-to-build-with-Java-8.patch
  * 0001-Simple-implementation-of-toolchains-https-github.com.patch
  * 0002-Revert-Update-compiler-source-target-to-JDK-11.patch
  * 0002-module-path-not-allowed-with-release-8.patch
  * 0003-Revert-Use-new-Collection-methods-added-in-Java-9.patch
  * 0004-Add-a-jdk9-profile-to-assure-that-we-are-jdk8-compat.patch
    + Integrated upstream in this version
* Mon May 16 2022 fstrba@suse.com
- Added patch:
  * 0001-Port-to-Maven-3.8.5.patch
    + Allow buiding against unpatched maven 3.8.5
* Fri May 13 2022 fstrba@suse.com
- Fix build with modello 2.0.0
* Tue May 10 2022 fstrba@suse.com
- Upgrade to version 4.0.0
  * Changes:
    +  Bump codecov/codecov-action from 2.0.1 to 2.0.2
    +  Bump codecov/codecov-action from 1 to 2.0.1
    +  Bump commons-compress from 1.20 to 1.21 in /xmvn-parent
    +  Change logic for JPMS detection by Javadoc MOJO
    +  Fix Javadoc generation for non-JPMS project with JDK 11
    +  Remove superflous JARs from assembly
    +  Create a backup file when injecting Manifest
    +  Attach site artifacts only in site lifecycle
    +  Rename xmvn-connector-aether to xmvn-connector
    +  Use try-with-resources to avoid resource leaks
    +  Remove unused AtomicFileCounter class
    +  Update Eclipse project settings
    +  Add separate build profile for code quality tools
    +  Remove prerequisites on Maven version
    +  Drop bisect tool
    +  Move release plugins to pluginManagement
    +  Move prerequisites on Maven version to xmvn-mojo
    +  Fix javadoc warning
    +  Bump junit from 4.12 to 4.13.1 in /xmvn-it/src/test/resources/testBisect
    +  Bump slf4jVersion from 1.8.0-beta4 to 2.0.0-alpha2 in /xmvn-parent
    +  Compile everything whith --release 11
    +  Fix assembly building with Maven Checkstyle Plugin 3.1.0+
    +  Update to latest Checkstyle
    +  Format code to conform to Checkstyle 8.44
    +  Untabify Maven build files
    +  Update Maven plugin versions
    +  Drop Ivy
    +  Drop Gradle
    +  Add support for compiler release setting
    +  Fix Javadoc generation for modular projects
    +  Add JPMS check to Javadoc MOJO
    +  Add missing license headers
    +  Disable I/O write test if the build is running as root
    +  Switch to SHA-256 in CacheManager
    +  Update dependency xmlunit.assertj to xmlunit.assertj3
    +  Fixes #56 - Honour source parameter in javadoc mojo
    +  Implement XMvn toolchain manager
    +  Fix requires generation for self-depending packages
    +  Remove redundant parentheses
    +  Remove redudnant use of this
    +  Relay on implicit access modifiers of interfaces
    +  Rely on implicit boxing
    +  Make use of diamond operator
    +  [test] Use use lambda expressions for creation of DeploymentResult
    +  Remove use of deprecated StringUtils methods
    +  [test] Port tests to JUnit 5
    +  Update to latest dependencies
    +  [test] Add missing assertions about XML output
    +  Use new Collection methods added in Java 9
    +  Remove uses of deprecated Class.newInstance() method
    +  Drop artifact resolution from JAVA_HOME
    +  Update to latest Maven plugin versions
    +  Update compiler source/target to JDK 11
    +  Update Eclipse project settings
    +  Make xmvn-subst honor settings for ignoring duplicate metadata
    +  Allow removing plugins during model validation
    +  Prefer namespaced metadata when duplicates are found
- Removed patches:
  * xmvn-gradle_4_4_1.patch
  * 0001-Fix-resolution-of-aliases-registered-by-add_maven_de.patch
    + Patches the inexisting xmvn-connector-gradle module
  * 0001-Prefer-namespaced-metadata-when-duplicates-are-found.patch
  * 0002-Make-xmvn-subst-honor-settings-for-ignoring-duplicat.patch
  * 0003-Fix-requires-generation-for-self-depending-packages.patch
    + Integrated upstream
- Added patches:
  * 0001-Mimic-maven-javadoc-plugin-for-source-and-release.patch
  * 0002-module-path-not-allowed-with-release-8.patch
    + make Xmvn Javadoc Mojo respect release and source arguments
  * 0001-Simple-implementation-of-toolchains-https-github.com.patch
    + consider toolchains if specifies in Xmvn Javadoc Mojo
  * 0001-Restore-possibility-to-build-with-Java-8.patch
  * 0002-Revert-Update-compiler-source-target-to-JDK-11.patch
  * 0003-Revert-Use-new-Collection-methods-added-in-Java-9.patch
  * 0004-Add-a-jdk9-profile-to-assure-that-we-are-jdk8-compat.patch
    + different fixes to be able to build with JDK8
* Thu Nov 21 2019 fstrba@suse.com
- Upgrade to upstream version 3.1.0
  * Requires maven-invoker >= 3.0
- Removed patches:
  * 0001-Fix-installer-plugin-loading.patch
  * 0001-Port-to-Gradle-4.2.patch
  * 0001-Port-to-Gradle-4.3.1.patch
  * 0001-Support-setting-Xdoclint-none-in-m-javadoc-p-3.0.0.patch
  * 0001-Fix-configuration-of-aliased-plugins.patch
  * 0001-Don-t-use-JAXB-for-converting-bytes-to-hex-string.patch
  * 0001-Use-apache-commons-compress-for-manifest-injection-a.patch
  * 0001-port-to-gradle-4.4.1.patch
  * 0001-Replace-JAXB-parser.patch
    + Integrated in this version
- Added patches:
  * 0001-Prefer-namespaced-metadata-when-duplicates-are-found.patch
  * 0002-Make-xmvn-subst-honor-settings-for-ignoring-duplicat.patch
    + upstream fixes to ignore duplicate metadata
  * 0003-Fix-requires-generation-for-self-depending-packages.patch
    + Downstream bug-fix with generation of metadata for
    self-depending packages
* Fri Mar 15 2019 fstrba@suse.com
- Initial packaging of xmvn-tools 3.0.0 and their dependencies from
  xmvn project
- Generate and customize ant build files in order to be able to
  build without maven
